@@ -69,7 +69,7 @@ spectral_correlation <- function(X, parallel = 1, pb = TRUE, method = 1, cor.met
   if (!any(output %in% c("est", "data.frame"))) stop("'output' must be 'est' or 'data.frame'") 
   
   # hopsize  
-  if (!is.numeric(hop.size) | hop.size < 0) stop("'parallel' must be a positive number") 
+  if (!is.numeric(hop.size) | hop.size < 0) stop("'hop.size' must be a positive number") 
   
   # adjust wl based on hope.size
   if (is.null(wl))
